==> jc-1.4.0.tar.gz: soot/tagkit/StdTagPrinter.h <==
// public class soot.tagkit.StdTagPrinter

// class file dependencies
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 78c9158d626879d1 soot_tagkit_StdTagPrinter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_StdTagPrinter_H_
#define _JC_soot_tagkit_StdTagPrinter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_tagkit_Tag$object;

// Typedefs
typedef struct _jc_soot_tagkit_StdTagPrinter$sub_refs	_jc_soot_tagkit_StdTagPrinter$sub_refs;
typedef struct _jc_soot_tagkit_StdTagPrinter$sub_nonrefs	_jc_soot_tagkit_StdTagPrinter$sub_nonrefs;
typedef struct _jc_soot_tagkit_StdTagPrinter$refs	_jc_soot_tagkit_StdTagPrinter$refs;
typedef struct _jc_soot_tagkit_StdTagPrinter$nonrefs	_jc_soot_tagkit_StdTagPrinter$nonrefs;
typedef struct _jc_soot_tagkit_StdTagPrinter$object	_jc_soot_tagkit_StdTagPrinter$object;

typedef const struct _jc_soot_tagkit_StdTagPrinter$vmethods	_jc_soot_tagkit_StdTagPrinter$vmethods;
typedef const struct _jc_soot_tagkit_StdTagPrinter$vtable	_jc_soot_tagkit_StdTagPrinter$vtable;
typedef const struct _jc_soot_tagkit_StdTagPrinter$vtype	_jc_soot_tagkit_StdTagPrinter$vtype;

// Constructors
extern void _jc_soot_tagkit_StdTagPrinter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tagkit_StdTagPrinter$object *);

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_StdTagPrinter$method$print$ec2b3e4722a20d7e(_jc_env *, struct _jc_soot_tagkit_StdTagPrinter$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_StdTagPrinter$method_info$print$ec2b3e4722a20d7e;

// Virtual methods structure
struct _jc_soot_tagkit_StdTagPrinter$vmethods {
	struct _jc_java_lang_String$object	*(*print$ec2b3e4722a20d7e)(_jc_env *, struct _jc_soot_tagkit_StdTagPrinter$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *);
};

// Vtable
struct _jc_soot_tagkit_StdTagPrinter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_StdTagPrinter$vmethods	soot_tagkit_StdTagPrinter;
};

// Vtype
struct _jc_soot_tagkit_StdTagPrinter$vtype {
	_jc_type			type;
	_jc_soot_tagkit_StdTagPrinter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_StdTagPrinter$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_StdTagPrinter$refs {
    _jc_soot_tagkit_StdTagPrinter$sub_refs	soot_tagkit_StdTagPrinter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_StdTagPrinter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_StdTagPrinter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_StdTagPrinter$sub_nonrefs	soot_tagkit_StdTagPrinter;
};

// Object instance structure
struct _jc_soot_tagkit_StdTagPrinter$object {
	_jc_soot_tagkit_StdTagPrinter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_StdTagPrinter$vtype	*vtype;
	_jc_soot_tagkit_StdTagPrinter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_StdTagPrinter$vtype _jc_soot_tagkit_StdTagPrinter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_StdTagPrinter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_StdTagPrinter$class_object;

#endif	/* _JC_soot_tagkit_StdTagPrinter_H_ */

==> jc-1.4.6.tar.gz: soot/tagkit/StdTagPrinter.h <==
// public class soot.tagkit.StdTagPrinter

// class file dependencies
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 78c9158d626879d1 soot_tagkit_StdTagPrinter

// header file dependencies
// @dep_header java_lang_Object

#include "java/lang/Object.h"

#ifndef _JC_soot_tagkit_StdTagPrinter_H_
#define _JC_soot_tagkit_StdTagPrinter_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_soot_tagkit_Tag$object;

// Typedefs
typedef struct _jc_soot_tagkit_StdTagPrinter$sub_refs	_jc_soot_tagkit_StdTagPrinter$sub_refs;
typedef struct _jc_soot_tagkit_StdTagPrinter$sub_nonrefs	_jc_soot_tagkit_StdTagPrinter$sub_nonrefs;
typedef struct _jc_soot_tagkit_StdTagPrinter$refs	_jc_soot_tagkit_StdTagPrinter$refs;
typedef struct _jc_soot_tagkit_StdTagPrinter$nonrefs	_jc_soot_tagkit_StdTagPrinter$nonrefs;
typedef struct _jc_soot_tagkit_StdTagPrinter$object	_jc_soot_tagkit_StdTagPrinter$object;

typedef const struct _jc_soot_tagkit_StdTagPrinter$vmethods	_jc_soot_tagkit_StdTagPrinter$vmethods;
typedef const struct _jc_soot_tagkit_StdTagPrinter$vtable	_jc_soot_tagkit_StdTagPrinter$vtable;
typedef const struct _jc_soot_tagkit_StdTagPrinter$vtype	_jc_soot_tagkit_StdTagPrinter$vtype;

// Constructors
extern void _jc_soot_tagkit_StdTagPrinter$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_soot_tagkit_StdTagPrinter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_java_lang_String$object *_jc_soot_tagkit_StdTagPrinter$method$print$ec2b3e4722a20d7e(_jc_env *, struct _jc_soot_tagkit_StdTagPrinter$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_soot_tagkit_StdTagPrinter$method_info$print$ec2b3e4722a20d7e;

// Virtual methods structure
struct _jc_soot_tagkit_StdTagPrinter$vmethods {
	struct _jc_java_lang_String$object	*(*print$ec2b3e4722a20d7e)(_jc_env *, struct _jc_soot_tagkit_StdTagPrinter$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_soot_tagkit_StdTagPrinter$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_soot_tagkit_StdTagPrinter$vmethods	soot_tagkit_StdTagPrinter;
};

// Vtype
struct _jc_soot_tagkit_StdTagPrinter$vtype {
	_jc_type			type;
	_jc_soot_tagkit_StdTagPrinter$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_soot_tagkit_StdTagPrinter$sub_refs {
};

// Reference instance fields (object)
struct _jc_soot_tagkit_StdTagPrinter$refs {
    _jc_soot_tagkit_StdTagPrinter$sub_refs	soot_tagkit_StdTagPrinter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_soot_tagkit_StdTagPrinter$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_soot_tagkit_StdTagPrinter$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_soot_tagkit_StdTagPrinter$sub_nonrefs	soot_tagkit_StdTagPrinter;
};

// Object instance structure
struct _jc_soot_tagkit_StdTagPrinter$object {
	_jc_soot_tagkit_StdTagPrinter$refs	refs[0];
	_jc_word		lockword;
	_jc_soot_tagkit_StdTagPrinter$vtype	*vtype;
	_jc_soot_tagkit_StdTagPrinter$nonrefs	nonrefs;
};

// Type structure
extern _jc_soot_tagkit_StdTagPrinter$vtype _jc_soot_tagkit_StdTagPrinter$type;

// Array types class info structures
_JC_DECL_ARRAYS(soot_tagkit_StdTagPrinter, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_soot_tagkit_StdTagPrinter$class_object;

#endif	/* _JC_soot_tagkit_StdTagPrinter_H_ */
